#!/bin/bash

NUMFRAMES=10
NUM=1

while [ $NUM -le $NUMFRAMES ]; do

echo "
set size 0.9,0.8
set border 31 lw 0.5
set xrange [-pi:pi]
set yrange [-1:1]
set xlabel '$\alpha$ (N/m)'
set ylabel '$\phi$ (s)'
plot sin(x+$NUM*2*pi/$NUMFRAMES)*sin(1+2*(x+$NUM*2*pi/$NUMFRAMES)) lw 1.2 noti" > plot$NUM.gp

echo '\documentclass{article}
\usepackage{graphicx,psfrag}
\usepackage{color}
\usepackage{bm}
\begin{document}
\thispagestyle{empty}
\begin{figure}[!h]
\begin{center}
\input{gpplot.tex}
\end{center}
\end{figure}
\end{document}' > gp2epspdfaux.tex

echo "set term pslatex color size 4/1.155,2.5/1.07
set out 'gpplot.tex' 
" > gp2epspdfauxtmpl.gp
cat plot$NUM.gp >> gp2epspdfauxtmpl.gp
echo "
set out ; set term X11" >> gp2epspdfauxtmpl.gp

gnuplot gp2epspdfauxtmpl.gp
latex -halt-on-error -interaction nonstopmode gp2epspdfaux.tex
dvips -D600 -E* -o gp2epspdfaux.eps gp2epspdfaux.dvi
epstool --bbox --copy --output plot$NUM.eps gp2epspdfaux.eps
rm gpplot.tex gp2epspdfaux.aux gp2epspdfaux.dvi gp2epspdfaux.eps gp2epspdfaux.log gp2epspdfaux.tex gp2epspdfauxtmpl.gp
epstopdf plot$NUM.eps

echo "plot$NUM.gp" >> auxxgp
echo "plot$NUM.eps" >> auxxeps
echo "plot$NUM.pdf" >> auxxpdf

let NUM=$NUM+1
done

pdftk $(cat auxxpdf) cat output plot.pdf

rm $(cat auxxpdf) $(cat auxxeps) $(cat auxxgp)
rm auxxgp auxxeps auxxpdf

xpdf plot.pdf

exit
